==> PyGFET-0.1.1a2.tar.gz: PyGFET-0.1.1a2/setup.py <==
#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Thu Dec 21 18:30:42 2017

@author: aguimera
"""

#  Copyright 2017 Anton Guimerà Brunet <anton.guimera@csic.es>
#
#  This file is part of PyGFET.
#
#  PyGFET is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  PyGFET is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.


from setuptools import setup, find_packages

# comment AGB

_version = '0.1.1a2'

long_description = """
                   Library for GFET analysis tools
                   """

install_requires = ['numpy',
                    'matplotlib',
                    'quantities>=0.12',
                    'scipy',
                    'neo>=0.5.2',
                    'nixio']

# Comment 01

console_scripts = ['PyDBView = PyDBView.PyDBView:main',
                   'GFETRecExp = PyGFETRecordExplorer.PyGFETRecordExplorer:main']

entry_points = {'console_scripts': console_scripts, }

classifiers = ['Development Status :: 3 - Alpha',
               'Environment :: Console',
               'Environment :: X11 Applications :: Qt',
               'Environment :: Win32 (MS Windows)',
               'Intended Audience :: Science/Research',
               'License :: OSI Approved :: GNU General Public License (GPL)',
               'Operating System :: Microsoft :: Windows',
               'Operating System :: POSIX',
               'Operating System :: POSIX :: Linux',
               'Operating System :: Unix',
               'Operating System :: OS Independent',
               'Programming Language :: Python',
               'Programming Language :: Python :: 2.7',
               'Topic :: Scientific/Engineering',
               'Topic :: Software Development :: User Interfaces']

setup(name="PyGFET",
      version=_version,
      description="GFET Analysis tools",
      long_description=long_description,
      author="Anton Guimerà-Brunet",
      author_email="anton.guimera@csic.es",
      maintainer="Anton Guimerà-Brunet",
      maintainer_email="anton.guimera@csic.es",
      url="https://github.com/aguimera/PyGFET",
      download_url="https://github.com/aguimera/PyGFET",
      license="GPLv3",
      packages=find_packages(),
      classifiers=classifiers,
      entry_points=entry_points,
      install_requires=install_requires,
      include_package_data=True,
      )

==> PyGFET-0.1.2b1.tar.gz: PyGFET-0.1.2b1/setup.py <==
#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Thu Dec 21 18:30:42 2017

@author: aguimera
"""

#  Copyright 2017 Anton Guimerà Brunet <anton.guimera@csic.es>
#
#  This file is part of PyGFET.
#
#  PyGFET is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  PyGFET is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.


from setuptools import setup, find_packages

_version = '0.1.2b1'

long_description = """
                   Library for GFET analysis tools                   
                   """

install_requires = ['pymysql',
                    'numpy',
                    'matplotlib',
                    'quantities>=0.12',
                    'scipy',
                    'neo>=0.5.2',
                    'nixio',
                    'xlsxwriter']

console_scripts = ['GFETDbView = PyGFET.GuiDBView.GuiDBView:main',
                   'GFETRecExp = PyGFET.GuiRecordView.GuiRecordExplorer:main',
                   'GFETCharactGui = PyGFET.GuiMeasure.GuiCharact:main',
                   'GFETStimGui = PyGFET.GuiStimulation.GuiStim:main']

entry_points = {'console_scripts': console_scripts, }

classifiers = ['Development Status :: 3 - Alpha',
               'Environment :: Console',
               'Environment :: X11 Applications :: Qt',
               'Environment :: Win32 (MS Windows)',
               'Intended Audience :: Science/Research',
               'License :: OSI Approved :: GNU General Public License (GPL)',
               'Operating System :: Microsoft :: Windows',
               'Operating System :: POSIX',
               'Operating System :: POSIX :: Linux',
               'Operating System :: Unix',
               'Operating System :: OS Independent',
               'Programming Language :: Python',
               'Programming Language :: Python :: 2.7',
               'Topic :: Scientific/Engineering',
               'Topic :: Software Development :: User Interfaces']

setup(name="PyGFET",
      version=_version,
      description="GFET Analysis tools",
      long_description=long_description,
      author="Anton Guimerà-Brunet",
      author_email="anton.guimera@csic.es",
      maintainer="Anton Guimerà-Brunet",
      maintainer_email="anton.guimera@csic.es",
      url="https://github.com/aguimera/PyGFET",
      download_url="https://github.com/aguimera/PyGFET",
      license="GPLv3",
      packages=find_packages(),
      classifiers=classifiers,
      entry_points=entry_points,
      install_requires=install_requires,
      include_package_data=True,
      )
